Skip to contents

CP decomposition of a tensor using Alternating Least Squares

Usage

cpDecomposition(tnsr, num_components = NULL, max_iter = 25, tol = 1e-05)

Arguments

tnsr

Tensor with K modes

num_components

the number of rank-1 K-Tensors to use in approximation

max_iter

maximum number of iterations if error stays above tol

tol

relative Frobenius norm error tolerance

Value

a list containing decomposition results