Skip to contents

Build comparable low-dimensional features for two weight-averaged denoised single-cell gene regulatory networks using non-linear network embedding

Usage

manifoldAlignment(X, Y, d = 30, nCores = parallel::detectCores())

Arguments

X

A gene regulatory network

Y

A gene regulatory network

d

The dimension of the low-dimensional feature space

nCores

An integer value. Defines the number of cores to be used (currently not used, kept for compatibility)

Value

A low-dimensional projection for the two gene regulatory networks used as input