- countMatrix
countMatrix
- gKO
gKO
- qc_mtThreshold
A decimal value between 0 and 1. Defines the maximum ratio of mitochondrial reads (mithocondrial reads / library size) present in a cell to be included in the analysis. It's computed using the symbol genes starting with 'MT-' non-case sensitive.
- qc_minLSize
An integer value. Defines the minimum library size required for a cell to be included in the analysis.
- nc_lambda
A continuous value between 0 and 1. Defines the multiplicative value (1-lambda) to be applied over the weaker edge connecting two genes to maximize the adjacency matrix directionality.
- nc_nNet
An integer value. The number of networks based on principal components regression to generate.
- nc_nCells
An integer value. The number of cells to subsample each time to generate a network.
- nc_nComp
An integer value. The number of principal components in PCA to generate the networks. Should be greater than 2 and lower than the total number of genes.
- nc_scaleScores
A boolean value (TRUE/FALSE), if TRUE, the weights will be normalized such that the maximum absolute value is 1.
- nc_symmetric
A boolean value (TRUE/FALSE), if TRUE, the weights matrix returned will be symmetric.
- nc_q
A decimal value between 0 and 1. Defines the cut-off threshold of top q% relationships to be returned.
- td_K
An integer value. Defines the number of rank-one tensors used to approximate the data using CANDECOMP/PARAFAC (CP) Tensor Decomposition.
- td_maxIter
An integer value. Defines the maximum number of iterations if error stay above td_maxError.
- td_maxError
A decimal value between 0 and 1. Defines the relative Frobenius norm error tolerance.
- td_nDecimal
An integer value indicating the number of decimal places to be used.
- ma_nDim
An integer value. Defines the number of dimensions of the low-dimensional feature space to be returned from the non-linear manifold alignment.